==> varbase_editor-9.2.12.zip: varbase_editor/README.md <==
# Varbase Editor

Integrates a rich editor into Varbase distribution.

## Features:
* Full media integration with CKEditor including caption and much more.
* LinkIt Integration for easy internal linking of content.
* Image enhancements and optimizations.
* Embeddable media and entities.
* Path fixing when uploading images or linking to content with absolute
 URLs directing to staging or development environments.
* Code Editor for Web Admins.

## Dependencies and Used Modules for Drupal
* [CKEditor Anchor Link](https://www.drupal.org/project/anchor_link)
* [Linkit - Enriched linking experience](https://www.drupal.org/project/linkit)
* [External Links](https://www.drupal.org/project/extlink)
* [Editor Advanced link](https://www.drupal.org/project/editor_advanced_link)
* [Pathologic](https://www.drupal.org/project/pathologic)
* [Image Resize Filter](https://www.drupal.org/project/image_resize_filter)
* [Embed](https://www.drupal.org/project/embed)
* [Entity Embed](https://www.drupal.org/project/entity_embed)
* [CKEditor BiDi Buttons](https://www.drupal.org/project/ckeditor_bidi)
* [Ace Code Editor](https://www.drupal.org/project/ace_editor)




## Use With [Varbase](https://www.drupal.org/project/varbase) Distribution:
This module is best used with [Varbase](https://www.drupal.org/project/varbase) distribution.

Can be installed with any Drupal site.
 Even if installed with the Minimal or Standard profile.
However, using it with [Varbase](https://www.drupal.org/project/varbase) gives you way much more cool stuff!

## [Varbase documentation](https://docs.varbase.vardot.com/dev-docs/understanding-varbase/core-components/varbase-editor)
Check out Varbase documentation for more details.

Join Our Slack Team for Feedback and Support
http://slack.varbase.vardot.com/

This module is sponsored and developed by [Vardot](https://www.drupal.org/vardot).

==> varbase_editor-10.0.18.zip: varbase_editor/README.md <==
# Varbase Editor

Integrates a rich editor into Varbase distribution.

## Features:
* Full media integration with CKEditor including caption and much more.
* LinkIt Integration for easy internal linking of content.
* Image enhancements and optimizations.
* Embeddable media and entities.
* Path fixing when uploading images or linking to content with absolute
 URLs directing to staging or development environments.
* Code Editor for Web Admins.

## Dependencies and Used Modules for Drupal
* [CKEditor Anchor Link](https://www.drupal.org/project/anchor_link)
* [Linkit - Enriched linking experience](https://www.drupal.org/project/linkit)
* [External Links](https://www.drupal.org/project/extlink)
* [Editor Advanced link](https://www.drupal.org/project/editor_advanced_link)
* [Pathologic](https://www.drupal.org/project/pathologic)
* [Embed](https://www.drupal.org/project/embed)
* [Entity Embed](https://www.drupal.org/project/entity_embed)
* [CKEditor BiDi Buttons](https://www.drupal.org/project/ckeditor_bidi)
* [Ace Code Editor](https://www.drupal.org/project/ace_editor)

### Rich editor
### Simple editor
### HTML code



## Use With [Varbase](https://www.drupal.org/project/varbase) Distribution:
This module is best used with [Varbase](https://www.drupal.org/project/varbase) distribution.

Can be installed with any Drupal site.
 Even if installed with the Minimal or Standard profile.
However, using it with [Varbase](https://www.drupal.org/project/varbase) gives you way much more cool stuff!

## [Varbase documentation](https://docs.varbase.vardot.com/dev-docs/understanding-varbase/core-components/varbase-editor)
Check out Varbase documentation for more details.

Join Our Slack Team for Feedback and Support
http://slack.varbase.vardot.com/

This module is sponsored and developed by [Vardot](https://www.drupal.org/vardot).
